==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_MX.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "Eliminar usuario de la tarjeta",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "Deck" : "Deck",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "{user} has shared the board %s with you." : "{user} ha compartido el tablero %s contigo. ",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "A kanban style project and personal management tool for Nextcloud" : "Una herramienta de administración de proyectos y personal estilo kanban",
    "Add a new stack" : "Agregar una nueva pila",
    "Submit" : "Enviar",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "All Boards" : "Todos los Tableros",
    "Archived boards" : "Tableros archivados",
    "Enter a card title" : "Ingresa el título de la tarjeta",
    "Add card" : "Agregar tarjeta",
    "Close" : "Cerrar",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Select users or groups to share with" : "Selecciona los usuarios o grupos con los cuales compartir",
    "No matching user or group found." : "No se encontraron coincidencias de usuarios o grupos.",
    "Loading" : "Cargando",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "Manage" : "Administrar",
    "Discard share" : "Descartar elemento compartido",
    "Create" : "Crear",
    "Create a new tag" : "Crear una nueva etiqueta",
    "Status" : "Estatus",
    "Title" : "Título",
    "Members" : "Miembros",
    "More actions" : "Más acciones",
    "Edit board" : "Editar el tablero",
    "Archive board" : "Archivar tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Delete board" : "Borrar tableros",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Deshacer borrado de tablero - De lo contrario el tablero se borrará durante la siguiente ejecución del cronjob. ",
    "Create new board" : "Crear un nuevo tablero",
    "New board title" : "Nuevo título del tablero",
    "by" : "por",
    "Modified:" : "Modificado:",
    "Created:" : "Creado:",
    "Choose a tag" : "Elije una etiqueta",
    "Add a tag" : "Agrega una etiqueta",
    "Select tags" : "Selecciona las etiquetas",
    "Assign users" : "Asingar usuarios",
    "Choose a user to assign" : "Elige un usuario a asignar",
    "Assign this card to a user" : "Asignar esta tarjeta al usuario",
    "Due date" : "Fecha de vencimiento",
    "Click to set" : "Da click aquí para establecer",
    "Remove due date" : "Eliminar fecha de expiración",
    "Description" : "Descripción",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Formatting help" : "Ayuda de formato",
    "Add a card description…" : "Agregar una descripción de tarjeta...",
    "Shared boards" : "Tableros compartidos",
    "Move board to archive" : "Mover el tablero al archivo",
    "Create a new board" : "Crear un nuevo tablero"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_MX.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "Eliminar usuario de la tarjeta",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "File already exists" : "El archivo ya existe",
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "{user} has shared the board %s with you." : "{user} ha compartido el tablero %s contigo. ",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "Done" : "Terminado",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "A kanban style project and personal management tool for Nextcloud" : "Una herramienta de administración de proyectos y personal estilo kanban",
    "Add a new stack" : "Agregar una nueva pila",
    "Submit" : "Enviar",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "All Boards" : "Todos los Tableros",
    "Archived boards" : "Tableros archivados",
    "Actions" : "Acciones",
    "Enter a card title" : "Ingresa el título de la tarjeta",
    "Add card" : "Agregar tarjeta",
    "Close" : "Cerrar",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Select users or groups to share with" : "Selecciona los usuarios o grupos con los cuales compartir",
    "Group" : "Grupo",
    "Circle" : "Círculo",
    "No matching user or group found." : "No se encontraron coincidencias de usuarios o grupos.",
    "Loading" : "Cargando",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "Manage" : "Administrar",
    "Discard share" : "Descartar elemento compartido",
    "Create" : "Crear",
    "Create a new tag" : "Crear una nueva etiqueta",
    "Status" : "Estatus",
    "Title" : "Título",
    "Members" : "Miembros",
    "More actions" : "Más acciones",
    "Edit board" : "Editar el tablero",
    "Archive board" : "Archivar tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Delete board" : "Borrar tableros",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Deshacer borrado de tablero - De lo contrario el tablero se borrará durante la siguiente ejecución del cronjob. ",
    "Create new board" : "Crear un nuevo tablero",
    "New board title" : "Nuevo título del tablero",
    "Cancel upload" : "Cancelar carga",
    "by" : "por",
    "Modified:" : "Modificado:",
    "Created:" : "Creado:",
    "Choose a tag" : "Elije una etiqueta",
    "Add a tag" : "Agrega una etiqueta",
    "Select tags" : "Selecciona las etiquetas",
    "Assign users" : "Asingar usuarios",
    "Choose a user to assign" : "Elige un usuario a asignar",
    "Assign this card to a user" : "Asignar esta tarjeta al usuario",
    "Due date" : "Fecha de vencimiento",
    "Click to set" : "Da click aquí para establecer",
    "Remove due date" : "Eliminar fecha de expiración",
    "Description" : "Descripción",
    "Attachments" : "Adjuntos",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Formatting help" : "Ayuda de formato",
    "Upload attachment" : "Cargar adjunto",
    "Add a card description…" : "Agregar una descripción de tarjeta...",
    "Shared boards" : "Tableros compartidos",
    "Move board to archive" : "Mover el tablero al archivo",
    "Create a new board" : "Crear un nuevo tablero",
    "Settings" : "Configuraciones "
},
"nplurals=2; plural=(n != 1);");
